import React, { useContext } from "react";
import { TextInput, View } from "react-native";
import styled, { ThemeContext } from "styled-components/native";
import { useTokens } from "../../libs";
const Wrapper = styled(View) `
  height: 40px;
  min-width: 328px;
  padding-horizontal: ${({ tokens }) => tokens["spacing-s"]}px;
  align-items: center;
  flex-direction: row;
  gap: ${({ tokens }) => tokens["spacing-xxs"]}px;
  border-radius: ${({ tokens }) => tokens["radius-s"]}px;
  background-color: ${({ tokens }) => tokens["colors-surface-transparent-subdued-default"]};
  overflow: hidden;
  color: ${({ tokens }) => tokens["colors-content-subdued-default-default"]};
`;
const StyledInput = styled(TextInput) `
  flex: 1;
  background-color: transparent;
  border-width: 0;
  color: ${({ tokens }) => tokens["colors-content-subdued-default-default"]};
`;
const TOKEN_KEYS = [
    "spacing-s",
    "spacing-xxs",
    "radius-s",
    "colors-surface-transparent-subdued-default",
    "colors-content-subdued-default-default",
];
export const Input = React.forwardRef(({ icon: Icon, ...props }, ref) => {
    const theme = useContext(ThemeContext);
    const themeType = theme?.colors?.type ?? "light";
    const tokens = useTokens(themeType, [...TOKEN_KEYS]);
    return (React.createElement(Wrapper, { tokens: tokens },
        !!Icon && React.createElement(Icon, { color: String(tokens["colors-content-subdued-default-default"]) }),
        React.createElement(StyledInput, { ...props, ref: ref, tokens: tokens })));
});
Input.displayName = "Input";
