import memoize from "lodash/memoize";
import { dark, light, spacing } from "./design-tokens";
// Override manquants
const overrideOther = {
    "radius-s": "8px",
    "radius-xs": "4px",
    "border-width-default": "1px",
    "border-width-focus": "2px",
    "margin-xs": "8px",
    "margin-s": "16px",
    "margin-m": "24px",
    "margin-l": "32px",
    "spacing-xs": "12px",
    "spacing-xxs": "8px",
};
const overrideColor = {
    light: {
        "surface-transparent-hover": "#0000000D",
        "surface-transparent-pressed": "#0000001A",
        "border-subdued-default-hover": "#D5D5D5",
        "border-subdued-default-pressed": "#C1C1C1",
    },
    dark: {
        "opacity-default-10": "#FFFFFF1A",
    },
};
function pxToNumber(value) {
    return Number(value.replace("px", ""));
}
export const useTokens = memoize((theme, usedTokens) => {
    const usedSet = new Set(usedTokens);
    const colors = {
        dark: { ...dark, ...overrideColor.dark },
        light: { ...light, ...overrideColor.light },
    }[theme];
    const tokens = {};
    Object.entries(colors).forEach(([key, value]) => {
        const colorKey = `colors-${key}`;
        if (usedSet.has(colorKey)) {
            tokens[colorKey] = value;
        }
    });
    [spacing, overrideOther].forEach((obj) => {
        Object.entries(obj).forEach(([key, value]) => {
            if (usedSet.has(key)) {
                tokens[key] = pxToNumber(value);
            }
        });
    });
    return tokens;
});
